Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/srunx/callbacks.py | 29 | 4 | 0 | 86%
src/srunx/cli/main.py | 222 | 67 | 2 | 70%
src/srunx/cli/workflow.py | 51 | 51 | 2 | 0%
src/srunx/client.py | 155 | 20 | 0 | 87%
src/srunx/exceptions.py | 3 | 0 | 0 | 100%
src/srunx/logging.py | 26 | 17 | 0 | 35%
src/srunx/models.py | 168 | 32 | 0 | 81%
src/srunx/runner.py | 125 | 6 | 0 | 95%
src/srunx/utils.py | 31 | 0 | 0 | 100%
Total | 810 | 197 | 4 | 76%

No items found using the specified filter.